..
   This is an autogenerated file from processors.rst

avatars.processors.GeolocationNormalizationProcessor
====================================================

.. autoclass:: avatars.processors.GeolocationNormalizationProcessor
   :members: